@@ -1,15 +1,18 @@
-import pandas as pd
-import plotly.express as px
-import numpy as np
 from datetime import datetime
 
-
+import numpy as np
+import pandas as pd
+import plotly.express as px
 from er_evaluation.utils import expand_grid
-from er_evaluation.estimators import estimates_table, pairwise_precision_design_estimate, pairwise_recall_design_estimate
+from er_evaluation.estimators import (
+    estimates_table, 
+    pairwise_precision_estimator, 
+    pairwise_recall_estimator
+)
 from er_evaluation.summary import (
     cluster_sizes,
     name_variation_rate,
-    homonimy_rate,
+    homonymy_rate,
     matching_rate
 )
 from er_evaluation.metrics import (
@@ -23,25 +26,23 @@ from er_evaluation.plots import (
     plot_cluster_sizes_distribution,
 )
 
-from pv_evaluation.benchmark import (
-    load_israeli_inventors_benchmark,
-    load_patentsview_inventors_benchmark,
-    load_lai_2011_inventors_benchmark,
-    load_als_inventors_benchmark,
-    load_ens_inventors_benchmark,
-    load_binette_2022_inventors_benchmark,
-)
+from pv_evaluation.benchmark import (load_als_inventors_benchmark,
+                                     load_binette_2022_inventors_benchmark,
+                                     load_ens_inventors_benchmark,
+                                     load_israeli_inventors_benchmark,
+                                     load_lai_2011_inventors_benchmark,
+                                     load_patentsview_inventors_benchmark)
 
 DEFAULT_ESTIMATORS = {
     # Point estimates and standard deviation estimates.
-    "pairwise precision": pairwise_precision_design_estimate,
-    "pairwise recall": pairwise_recall_design_estimate,
+    "pairwise precision": pairwise_precision_estimator,
+    "pairwise recall": pairwise_recall_estimator,
 }
 DEFAULT_INVENTORS_SAMPLES_WEIGHTS = {
     # Dataset and parameters to pass to the estimator.
     "binette-sample": {
         "sample": load_binette_2022_inventors_benchmark(),
-        "weights": 1 / cluster_sizes(load_binette_2022_inventors_benchmark()),
+        "weights": "cluster_size",
     },
 }
 # Default benchmarks to run.
@@ -73,11 +74,11 @@ def inventor_summary_trend_plot(persistent_inventor, names):
     persistent_inventor.set_index("mention_id", inplace=True)
 
     disambiguation_names = [s for s in persistent_inventor.columns.values if s.startswith("disamb")]
-    disambiguations = {s.lstrip("disamb_inventor_id_"):persistent_inventor[s].dropna() for s in disambiguation_names}
+    disambiguations = {s.lstrip("disamb_inventor_id_"): persistent_inventor[s].dropna() for s in disambiguation_names}
 
     metrics = {
         "Matching rate": lambda x: matching_rate(x),
-        "Homonimy rate": lambda x: homonimy_rate(x, names),
+        "Homonimy rate": lambda x: homonymy_rate(x, names),
         "Name variation rate": lambda x: name_variation_rate(x, names),
     }
 
@@ -94,7 +95,7 @@ def inventor_summary_trend_plot(persistent_inventor, names):
         symbol="metric",
         color_discrete_sequence=px.colors.qualitative.Vivid,
     )
-    fig.update_layout(yaxis_range=(0,1))
+    fig.update_layout(yaxis_range=(0, 1))
 
     return fig
 
@@ -118,11 +119,11 @@ def inventor_estimates_trend_plot(persistent_inventor, samples_weights=None, est
     if samples_weights is None:
         samples_weights = DEFAULT_INVENTORS_SAMPLES_WEIGHTS
 
-    persistent_inventor["mention_id"] = "US" +persistent_inventor.patent_id + "-" + persistent_inventor.sequence
+    persistent_inventor["mention_id"] = "US" + persistent_inventor.patent_id + "-" + persistent_inventor.sequence
     persistent_inventor.set_index("mention_id", inplace=True)
 
     disambiguation_names = [s for s in persistent_inventor.columns.values if s.startswith("disamb")]
-    disambiguations = {s.lstrip("disamb_inventor_id_"):persistent_inventor[s].dropna() for s in disambiguation_names}
+    disambiguations = {s.lstrip("disamb_inventor_id_"): persistent_inventor[s].dropna() for s in disambiguation_names}
 
     computed_metrics = estimates_table(disambiguations, samples_weights=samples_weights, estimators=estimators)
     computed_metrics["date"] = pd.to_datetime([datetime.strptime(d, "%Y%m%d") for d in computed_metrics["prediction"]])
@@ -377,7 +378,7 @@ def plot_name_variation_rates(disambiguations, names):
     return fig
 
 
-def plot_homonimy_rates(disambiguations, names):
+def plot_homonymy_rates(disambiguations, names):
     """
     Plot homonimy rates for a set of given disambiguations
 
@@ -389,7 +390,7 @@ def plot_homonimy_rates(disambiguations, names):
         Plotly figure.
     """
 
-    rates = [homonimy_rate(disambiguations[f], names=names) for f in disambiguations.keys()]
+    rates = [homonymy_rate(disambiguations[f], names=names) for f in disambiguations.keys()]
     data = pd.DataFrame({"Homonimy rate": rates, "Disambiguation": disambiguations.keys(), "none": ""})
 
     fig = px.bar(data, x="none", y="Homonimy rate", color="Disambiguation", barmode="group")
